@@ -4,7 +4,7 @@ from fastapi_amis_admin.amis_admin.admin import AdminApp, ModelAdmin
 from fastapi_amis_admin.crud.utils import schema_create_by_schema
 from starlette.requests import Request
 from fastapi_user_auth.admin import UserLoginFormAdmin, GroupAdmin, PermissionAdmin, UserAdmin, \
-    UserRegFormAdmin, RoleAdmin
+    UserRegFormAdmin, RoleAdmin, UserInfoFormAdmin
 from fastapi_user_auth.auth import AuthRouter
 
 
@@ -14,6 +14,7 @@ class UserAuthApp(AdminApp, AuthRouter):
     # default admin
     UserLoginFormAdmin: Type[UserLoginFormAdmin] = UserLoginFormAdmin
     UserRegFormAdmin: Type[UserRegFormAdmin] = UserRegFormAdmin
+    UserInfoFormAdmin: Type[UserInfoFormAdmin] = UserInfoFormAdmin
     UserAdmin: Type[UserAdmin] = UserAdmin
     RoleAdmin: Type[ModelAdmin] = RoleAdmin
     GroupAdmin: Type[ModelAdmin] = GroupAdmin
@@ -31,10 +32,15 @@ class UserAuthApp(AdminApp, AuthRouter):
                                        or schema_create_by_schema(self.auth.user_model, 'UserRegIn',
                                                                   include={'username', 'password', 'email'})
         self.UserRegFormAdmin.schema_submit_out = self.UserRegFormAdmin.schema_submit_out or self.schema_user_login_out
-
+        self.UserInfoFormAdmin.schema = self.UserInfoFormAdmin.schema \
+                                        or schema_create_by_schema(self.auth.user_model, 'UserInfoForm',
+                                                                   exclude={'id', 'username', 'password', 'is_active',
+                                                                            'parent_id', 'point', 'create_time'})
+        self.UserInfoFormAdmin.schema_submit_out = self.UserInfoFormAdmin.schema_submit_out or self.schema_user_info
         # register admin
         self.register_admin(self.UserLoginFormAdmin,
                             self.UserRegFormAdmin,
+                            self.UserInfoFormAdmin,
                             self.UserAdmin,
                             self.RoleAdmin,
                             self.GroupAdmin,
@@ -42,6 +48,5 @@ class UserAuthApp(AdminApp, AuthRouter):
                             )
 
     async def has_page_permission(self, request: Request) -> bool:
-        return await super().has_page_permission(request) and await request.auth.requires(roles='admin', response=False)(request)
-
-
+        return (await super().has_page_permission(request)
+                and await request.auth.requires(roles='admin', response=False)(request))
