@@ -8,6 +8,8 @@ from sqlmodel import SQLModel, Relationship, select
 from sqlmodel.ext.asyncio.session import AsyncSession
 from sqlmodel.sql.expression import SelectOfScalar
 
+SelectOfScalar.inherit_cache = True
+
 
 class SQLModelTable(SQLModel):
     id: int = Field(default=None, primary_key=True, nullable=False)
@@ -16,40 +18,40 @@ class SQLModelTable(SQLModel):
 class UserRoleLink(SQLModel, table=True):
     __tablename__ = 'auth_user_roles'
     user_id: Optional[int] = Field(
-        default=None, foreign_key="auth_user.id", primary_key=True
+        default=None, foreign_key="auth_user.id", primary_key=True, nullable=False
     )
     role_id: Optional[int] = Field(
-        default=None, foreign_key="auth_role.id", primary_key=True
+        default=None, foreign_key="auth_role.id", primary_key=True, nullable=False
     )
 
 
 class UserGroupLink(SQLModel, table=True):
     __tablename__ = 'auth_user_groups'
     user_id: Optional[int] = Field(
-        default=None, foreign_key="auth_user.id", primary_key=True
+        default=None, foreign_key="auth_user.id", primary_key=True, nullable=False
     )
     group_id: Optional[int] = Field(
-        default=None, foreign_key="auth_group.id", primary_key=True
+        default=None, foreign_key="auth_group.id", primary_key=True, nullable=False
     )
 
 
 class GroupRoleLink(SQLModel, table=True):
     __tablename__ = 'auth_group_roles'
     group_id: Optional[int] = Field(
-        default=None, foreign_key="auth_group.id", primary_key=True
+        default=None, foreign_key="auth_group.id", primary_key=True, nullable=False
     )
     role_id: Optional[int] = Field(
-        default=None, foreign_key="auth_role.id", primary_key=True
+        default=None, foreign_key="auth_role.id", primary_key=True, nullable=False
     )
 
 
 class RolePermissionLink(SQLModel, table=True):
     __tablename__ = 'auth_role_permissions'
     role_id: Optional[int] = Field(
-        default=None, foreign_key="auth_role.id", primary_key=True
+        default=None, foreign_key="auth_role.id", primary_key=True, nullable=False
     )
     permission_id: Optional[int] = Field(
-        default=None, foreign_key="auth_permission.id", primary_key=True
+        default=None, foreign_key="auth_permission.id", primary_key=True, nullable=False
     )
 
 
@@ -59,9 +61,11 @@ class UserUsername(SQLModel):
         sa_column=Column(String(32), unique=True, index=True, nullable=False)
     )
 
-class PasswordStr(SecretStr,str):
+
+class PasswordStr(SecretStr, str):
     pass
 
+
 class UserPassword(SQLModel):
     password: PasswordStr = Field(
         title='密码', max_length=128,
